/**
 * 
 * $Id: CSTextP.h,v 1.2 2001/02/10 15:03:19 amai Exp $
 *
 * Copyright (C) 2000, 2001 LessTif Development Team
 *
 * This file is part of the GNU LessTif Library.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 **/
 
/*
   These are all only stubs, etc.
   We don't really have CSText ...
*/

#ifndef _XM_CSTEXTP_H
#define _XM_CSTEXTP_H

#include <Xm/Xm.h>
#include <Xm/CSText.h>

#ifdef __cplusplus
extern "C" {
#endif

typedef struct _XmCSTextPart {
  int dummy;
} XmCSTextPart;

typedef struct _XmCSTextRec {
    CorePart core;
    XmPrimitivePart primitive;
    XmCSTextPart cstext;
} XmCSTextRec;

/* Define class part structure */
typedef struct {
    XtPointer extension;
} CSTextClassPart;

typedef struct _XmCSTextClassRec {
  CoreClassPart core_class;
  XmPrimitiveClassPart primitive_class;
  CSTextClassPart cstext_class;
} XmCSTextClassRec;

extern XmCSTextClassRec xmCSTextClassRec;

#ifdef __cplusplus
}
#endif

#endif /* _XM_CSTEXTP_H */
